get_parquet_header

Function get_parquet_header 

pub fn get_parquet_header(
    m_type: MeasurementType,
    is_sessions: bool,
) -> Vec<&'static str>
Returns the fixed superset of columns for a measurement type. The session column is only included for feed measurements with sessions enabled.