write_batch_to_parquet

Function write_batch_to_parquet 

pub fn write_batch_to_parquet(
    writer: &mut SerializedFileWriter<File>,
    batch: &mut [ParquetDataRow],
    headers: &[&str],
) -> Result<(), ParquetError>
Writes a batch of ParquetDataRow to the Parquet file using the provided writer. The batch is sorted by reply source address for better compression.