write_results_parquet

Function write_results_parquet 

pub fn write_results_parquet(
    rx: UnboundedReceiver<ReplyBatch>,
    config: WriteConfig<'_>,
)
Write results to a Parquet file as they are received from the channel. This function processes the results in batches to optimize writing performance.

Arguments

  • rx - The receiver channel that receives the results.
  • config - The configuration for writing results, including file handle, metadata, and measurement type.